@@ -6,7 +6,7 @@ use Moo;
 use MooX::Types::MooseLike::Base qw(ArrayRef Str);
 use namespace::autoclean;
 
-our $VERSION = '2.010';
+our $VERSION = '2.011';
 
 extends qw(
     Locale::TextDomain::OO::Extract::Base::RegexBasedExtractor
@@ -901,19 +901,19 @@ __END__
 Locale::TextDomain::OO::Extract::JavaScript
 - Extracts internationalization data from JavaScript code
 
-$Id: JavaScript.pm 683 2017-08-22 18:41:42Z steffenw $
+$Id: JavaScript.pm 693 2017-09-02 09:20:30Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/extract/trunk/lib/Locale/TextDomain/OO/Extract/JavaScript.pm $
 
 =head1 VERSION
 
-2.010
+2.011
 
 =head1 DESCRIPTION
 
 This module extracts internationalization data from JavaScript code.
 
-Implemented Rules:
+Implemented rules:
 
  # Gettext::Loc
  loc_('...
@@ -1081,8 +1081,9 @@ Also possible all functions with N in front like Nloc_, N__, Ngettext, ... to pr
         $extractor->clear;
         $extractor->filename($_);            # dir/filename for reference
         $extractor->content_ref( \( path($_)->slurp_utf8 ) );
-        $exttactor->category('LC_Messages'); # set defaults or q{} is used
-        $extractor->domain('default');       # set defaults or q{} is used
+        $extractor->project('my project');   # set or default undef is used
+        $extractor->category('LC_MESSAGES'); # set or default q{} is used
+        $extractor->domain('my domain');     # set or default q{} is used
         $extractor->extract;
     }
     ... = $extractor->lexicon_ref;
