@@ -7,7 +7,7 @@ use Moo;
 use MooX::Types::MooseLike::Base qw(ArrayRef Str);
 use namespace::autoclean;
 
-our $VERSION = '2.010';
+our $VERSION = '2.011';
 
 extends qw(
     Locale::TextDomain::OO::Extract::Base::RegexBasedExtractor
@@ -951,13 +951,13 @@ __END__
 Locale::TextDomain::OO::Extract::Perl
 - Extracts internationalization data from Perl source code
 
-$Id: Perl.pm 683 2017-08-22 18:41:42Z steffenw $
+$Id: Perl.pm 693 2017-09-02 09:20:30Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/extract/trunk/lib/Locale/TextDomain/OO/Extract/Perl.pm $
 
 =head1 VERSION
 
-2.010
+2.011
 
 =head1 DESCRIPTION
 
@@ -1101,24 +1101,6 @@ Quote and escape any text like: ' text {placeholder} \\ \' ' or q{ text {placeho
     use Locale::TextDomain::OO::Extract::Perl;
     use Path::Tiny qw(path);
 
-    my $extractor = Locale::TextDomain::OO::Extract::Perl->new;
-    for ( @files ) {
-        $extractor->clear;
-        $extractor->filename($_);            # dir/filename for reference
-        $extractor->content_ref( \( path($_)->slurp_utf8 ) );
-        $exttactor->category('LC_Messages'); # set defaults or q{} is used
-        $extractor->domain('default');       # set defaults or q{} is used
-        $extractor->extract;
-    }
-    ... = $extractor->lexicon_ref;
-
-=head1 SUBROUTINES/METHODS
-
-=head2 method new
-
-All parameters are optional.
-See Locale::TextDomain::OO::Extract to replace the defaults.
-
     my $extractor = Locale::TextDomain::OO::Extract::Perl->new(
         # optional filter parameter, the default is ['all'],
         # the following means:
@@ -1132,6 +1114,25 @@ See Locale::TextDomain::OO::Extract to replace the defaults.
             !Maketext
         ) ],
     );
+    for ( @files ) {
+        $extractor->clear;
+        $extractor->filename($_);            # dir/filename for reference
+        $extractor->content_ref( \( path($_)->slurp_utf8 ) );
+        $extractor->project('my project');   # set or default undef is used
+        $extractor->category('LC_MESSAGES'); # set or default q{} is used
+        $extractor->domain('my domain');     # set or default q{} is used
+        $extractor->extract;
+    }
+    ... = $extractor->lexicon_ref;
+
+=head1 SUBROUTINES/METHODS
+
+=head2 method new
+
+All parameters are optional.
+See Locale::TextDomain::OO::Extract to replace the defaults.
+
+    my $extractor = Locale::TextDomain::OO::Extract::Perl->new;
 
 =head2 method filter
 
